/*
    This file is part of KDE.

    SPDX-FileCopyrightText: 2010 Sebastian Kügler <sebas@kde.org>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef ATTICA_PUBLISHERPARSER_H
#define ATTICA_PUBLISHERPARSER_H

#include "publisher.h"
#include "parser.h"

namespace Attica
{

class Publisher::Parser : public Attica::Parser<Publisher>
{
private:
    Publisher parseXml(QXmlStreamReader &xml) override;
    QStringList xmlElement() const override;
};

}

#endif
